:py:mod:`autodoc2.sphinx`
=========================

.. py:module:: autodoc2.sphinx

.. autodoc2-docstring:: autodoc2.sphinx
   :allowtitles:

Submodules
----------

.. toctree::
   :titlesonly:
   :maxdepth: 1

   autodoc2.sphinx.docstring
   autodoc2.sphinx.summary
   autodoc2.sphinx.utils
   autodoc2.sphinx.extension
   autodoc2.sphinx.autodoc
